@@ -4,6 +4,7 @@ import logging
 
 import pytz
 import tzlocal
+import struct
 from apscheduler.jobstores.sqlalchemy import SQLAlchemyJobStore
 from apscheduler.schedulers.background import BackgroundScheduler
 from apscheduler.triggers.cron import CronTrigger
@@ -110,6 +111,10 @@ def setup_scheduler(manager):
             timezone = None
     except pytz.UnknownTimeZoneError:
         timezone = None
+    except struct.error as e:
+        # Hiding exception that may occur in tzfile.py seen in entware
+        log.warning('Hiding exception from tzlocal: %s', e)
+        timezone = None
     if not timezone:
         # The default sqlalchemy jobstore does not work when there isn't a name for the local timezone.
         # Just fall back to utc in this case
