@@ -452,7 +452,10 @@ class InputRSS(object):
         # Save last spot in rss
         if rss.entries:
             log.debug('Saving location in rss feed.')
-            task.simple_persistence['%s_last_entry' % url_hash] = rss.entries[0].title + rss.entries[0].get('guid', '')
+            try:
+                task.simple_persistence['%s_last_entry' % url_hash] = rss.entries[0].title + rss.entries[0].get('guid', '')
+            except AttributeError:
+                log.debug('rss feed location saving skipped: no title information in first entry')
 
         if ignored:
             if not config.get('silent'):
