@@ -1,11 +1,13 @@
 from __future__ import unicode_literals, division, absolute_import
 import logging
-from flexget.plugin import register_plugin
+
+from flexget import plugin
+from flexget.event import event
 
 log = logging.getLogger("btjunkie")
 
 
-class UrlRewriteBtJunkie:
+class UrlRewriteBtJunkie(object):
     """BtJunkie urlrewriter."""
 
     def url_rewritable(self, task, entry):
@@ -13,6 +15,9 @@ class UrlRewriteBtJunkie:
 
     def url_rewrite(self, task, entry):
         entry['url'] = entry['url'].replace('btjunkie.org', 'dl.btjunkie.org')
-        entry['url'] = entry['url'] + "/download.torrent"
+        entry['url'] += "/download.torrent"
 
-register_plugin(UrlRewriteBtJunkie, 'btjunkie', groups=['urlrewriter'])
+
+@event('plugin.register')
+def register_plugin():
+    plugin.register(UrlRewriteBtJunkie, 'btjunkie', groups=['urlrewriter'], api_ver=2)
