@@ -100,14 +100,14 @@ class UrlRewriteIPTorrents(object):
             log.debug("Got the URL: %s" % entry['url'])
         if entry['url'].startswith(BASE_URL + '/t?'):
             # use search
-            results = self.search(entry)
+            results = self.search(task, entry)
             if not results:
                 raise UrlRewritingError("No search results found")
             # TODO: Search doesn't enforce close match to title, be more picky
             entry['url'] = results[0]['url']
 
     @plugin.internet(log)
-    def search(self, entry, config=None):
+    def search(self, task, entry, config=None):
         """
         Search for name from iptorrents
         """
